# pylaunch

Simple library for working with the DIAL Protocol.

DIAL -- "DIscovery And Launch" is a simple protocol that second-screen devices can use to discover and launch apps on first-screen devices.
